@@ -12,7 +12,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.199_05';
+our $VERSION = '0.199_06';
 
 use RDF::RDFa::Generator::HTML::Head;
 use RDF::RDFa::Generator::HTML::Hidden;
@@ -149,6 +149,20 @@ sub nodes
 
 =back
 
+=head1 UPGRADING TO 0.200
+
+The recommended upgrade path is to migrate your application to use
+L<Attean> rather than L<RDF::Trine> as your RDF library. If that is
+not an option, you may continue to use L<RDF::Trine>, by using a
+compatibility layer.  If you are using this module directly, to
+upgrade from earlier releases, you would simply add
+
+ use RDF::TrineX::Compatibility::Attean;
+
+alongside the import of this module. It is in a separate distribution
+that needs to be installed. If you use the L<RDF::Trine::Serializer>
+methods, you should instead use L<RDF::Trine::Serializer::RDFa>.
+
 =head1 NOTE
 
 Version 0.200 introduced a large number of changes to be compatible
